Calculates pairwise genetic identity between all samples. If
deme_level = TRUE this is averaged over all individuals within a
deme, to produce average pairwise relatedness within and between demes.
Each time point in the sample is considered independently, and output as a
list.
get_identity_matrix(sim_output, deme_level = FALSE)simulation output from sim_falciparum().
if TRUE then return pairwise identity at the deme
level, averaged over all individuals within each deme. Otherwise return at
the individual level.